pub fn render_output(output: &SearchOutput) -> StringExpand description
Render the human-readable form of a search: results, then the reference block, then a one-line note when the search did not actually answer.
pub fn render_output(output: &SearchOutput) -> StringRender the human-readable form of a search: results, then the reference block, then a one-line note when the search did not actually answer.